@@ -347,10 +347,7 @@ namespace eval ::viewer {
 
       proc destroy {} {
         variable v_e
-       if [catch {namespace inscope $v_e destroy} err] {
-          puts "deleteing $v_e"
-          puts $err
-        }
+        catch {namespace inscope $v_e destroy}
         if [catch {namespace delete [namespace current]} err] {
           puts "deleting [namespace current]"
           puts $err
@@ -505,7 +502,6 @@ namespace eval ::view_output {
 
 proc viewer_window {w title parent} {
   global cvscfg
-  global cvsglb
   global tcl_platform
 
   toplevel $w
@@ -515,7 +511,7 @@ proc viewer_window {w title parent} {
   wm protocol $w WM_DELETE_WINDOW "$w.close invoke"
 
   text $w.text -setgrid yes -relief sunken -border 2 \
-      -bg $cvsglb(textbg) \
+      -bg white -fg black \
       -exportselection 1 -height 30 \
       -yscroll "$w.scroll set"
   bind $w.text <KeyPress> {
@@ -550,18 +546,17 @@ proc viewer_window {w title parent} {
 
   scrollbar $w.scroll -relief sunken -command "$w.text yview"
   frame $w.bottom
-  button $w.bottom.srchbtn -text Search -highlightbackground $cvsglb(bg) \
+  button $w.bottom.srchbtn -text Search \
     -command "$parent\::search"
   entry $w.bottom.entry -width 20 -textvariable searchstr
   bind $w.bottom.entry <Return> "$parent\::search"
   
-  button $w.save -text "Save to File" -highlightbackground $cvsglb(bg) \
+  button $w.save -text "Save to File" \
    -command "save_viewcontents $w"
-  button $w.close -text "Close" -highlightbackground $cvsglb(bg) \
+  button $w.close -text "Close" \
    -command "catch {$parent\::destroy}; destroy $w; exit_cleanup 0"
   button $w.stop -text "Stop" -bg red4 -fg white \
       -activebackground red4 -activeforeground white \
-      -highlightbackground $cvsglb(bg) \
       -state [expr {$cvscfg(allow_abort) ? {normal} : {disabled}}] \
       -command "$parent\::abort"
   pack $w.bottom -side bottom -fill x ;#-padx 25
@@ -640,3 +635,50 @@ proc search_textwidget { wtx } {
   set cvsglb(last_searchstr) $cvsglb(searchstr)
 }
 
+proc search_listbox_init {} {
+# Initialize the globals for searches
+  global cvsglb
+
+  if {! [info exists cvsglb(searchstr)] } {
+    set cvsglb(searchstr) ""
+    set cvsglb(last_searchstr) ""
+  }
+  set cvsglb(lsearchidx) 0
+}
+
+proc search_listbox { lbx } {
+# Search a listbox
+  global cvsglb
+
+  gen_log:log T "ENTER ($lbx)"
+
+  gen_log:log D "search string = \"$cvsglb(searchstr)\""
+  gen_log:log D "search index = \"$cvsglb(lsearchidx)\""
+
+  set ndx [$lbx index end]
+  if {$cvsglb(searchstr) != $cvsglb(last_searchstr)} {
+    set cvsglb(lsearchidx) 0
+    for {set i 0} {$i < $ndx} {incr i} {
+      $lbx itemconfigure $i -background $cvsglb(bg)
+    }
+  }
+  if {$cvsglb(lsearchidx) > $ndx} {
+    gen_log:log D "No more matches"
+    return
+  }
+  for {set i $cvsglb(lsearchidx)} {$i < $ndx} {incr i} {
+    set str [$lbx get $i]
+    if {[string match "*$cvsglb(searchstr)*" $str]} {
+      gen_log:log D "MATCH $str $cvsglb(searchstr)"
+      set cvsglb(lsearchidx) $i
+      $lbx itemconfigure $i -background $cvsglb(hlbg)
+      $lbx see $i
+      break
+    } else {
+      $lbx itemconfigure $i -background $cvsglb(bg)
+    }
+  }
+  set cvsglb(last_searchstr) $cvsglb(searchstr)
+  incr cvsglb(lsearchidx)
+}
+
