@@ -1,4 +1,3 @@
-
 #!/bin/sh
 #-*-tcl-*-
 # the next line restarts using wish \
@@ -74,7 +73,7 @@ set cvscfg(bitmapdir) [file join $TclRoot tkcvs bitmaps]
 #puts "TCDIR $TCDIR"
 #puts "BITMAPDIR $cvscfg(bitmapdir)"
 
-set cvscfg(version) "8.2.2"
+set cvscfg(version) "8.2.3"
 
 if {! [info exists cvscfg(editorargs)]} {
   set cvscfg(editorargs) {}
@@ -113,7 +112,7 @@ if {[file exists $optfile]} {
 ::picklist::load
 
 # Set some defaults
-set cvsglb(sort_pref) { filecol -decreasing }
+set cvsglb(sort_pref) [list $cvscfg(sortcol) "-decreasing"]
 set cvsglb(commit_comment) ""
 set cvsglb(cvs_version) ""
 set cvsglb(svn_version) ""
@@ -122,108 +121,191 @@ if {$cvscfg(use_cvseditor) && ![info exists cvscfg(terminal)]} {
   cvserror "cvscfg(terminal) is required if cvscfg(use_cvseditor) is set"
 }
 
-if {! [get_cde_params]} {
-  # Fonts.
-  # First, see what the native menu font is.
-  # This makes it look "normal" on Windows.
-  . configure -menu .native
-  menu .native
-  set menufont [lindex [.native configure -font] 4]
-  destroy .native
-  # Hilight colors.  Get the colorful ones.
-  entry .testent
-  set cvsglb(textbg) white
-  set cvsglb(textfg) black
-  set cvsglb(readonlybg) gray96
-  set cvsglb(hlbg) [lindex [.testent configure -selectbackground] 4]
-  set cvsglb(hlfg) [lindex [.testent configure -selectforeground] 4]
-  if {$cvsglb(hlfg) eq {} } {
-    # This happens on the Mac
-    set cvsglb(hlfg) [lindex [.testent configure -foreground] 4]
-  }
-  set hlbg_rgb [winfo rgb .testent $cvsglb(hlbg)]
-  set cvscfg(listboxfont) [lindex [.testent configure -font] 4]
-  destroy .testent
+# Hilight colors.  Get the colorful ones.
+entry .testent
+set cvsglb(textbg) white
+set cvsglb(textfg) black
+set cvsglb(hlbg) [lindex [.testent configure -selectbackground] 4]
+set cvsglb(hlfg) [lindex [.testent configure -selectforeground] 4]
+if {$cvsglb(hlfg) eq {} } {
+  # This happens on the Mac
+  set cvsglb(hlfg) [lindex [.testent configure -foreground] 4]
+}
+set cvscfg(listboxfont) [lindex [.testent configure -font] 4]
+destroy .testent
 
-  # Find out what the default gui font is
+
+set WSYS [tk windowingsystem]
+#puts "Windowing sytem is $WSYS"
+set theme_system "unknown"
+
+if {$WSYS eq "x11"} {
+  # If X11, see if we can sense our environment somehow
   label .testlbl -text "LABEL"
-  if { [info exists cvscfg(guifont)] } {
-    # If you set a guifont, I'm going to assume you want to use it for
-    # the menus too.
-    set menufont $cvscfg(guifont)
+  if [get_cde_params] {
+    set theme_system "CDE" 
+    # Find out what the default gui font is
+    if { ! [info exists cvscfg(guifont)] } {
+      # Find out what the tk default is
+      set cvscfg(guifont) [lindex [.testlbl configure -font] 4]
+    }
+    # Put the Help menu back on the right
+    if {$tk_version >= 8.5} {
+      tk::classic::restore menu
+    }
+    #set cvsglb(canvbg) [lindex [.testlbl configure -background] 4]
+    set cvsglb(canvbg) $cvsglb(shadow)
+  } elseif [get_gtk_params] {
+    set theme_system "GTK"
+    if { ! [info exists cvscfg(guifont)] } {
+      set cvscfg(guifont) [lindex [.testlbl configure -font] 4]
+      if {$tk_version >= 8.5} {
+       font configure TkDefaultFont -size 9
+       set cvscfg(guifont) TkDefaultFont
+       option add *Menu.font $cvscfg(guifont)
+       option add *Label.font $cvscfg(guifont)
+       option add *Button.font $cvscfg(guifont)
+      }
+    }
+    # in KDE or Gnome or some such.  It rather rudely sets all the Tk
+    # backgrounds the same which I don't like, so I'm going to use the same
+    # trick I use for CDE to give the canvases a little shading.
+    set cvsglb(bg) [lindex [.testlbl cget -background] 0]
+    set cvsglb(fg) [lindex [.testlbl cget -foreground] 0]
+    set cvsglb(canvbg) [rgb_shadow $cvsglb(bg)]
   } else {
-    # Find out what the tk default is
-    set cvscfg(guifont) [lindex [.testlbl configure -font] 4]
+    set bg  [lindex [.testlbl cget -background] 0]
+    set fg  [lindex [.testlbl cget -foreground] 0]
+    set hlbg "#4a6984"
+    set hlfg "#ffffff"
+    set textbg "#ffffff"
+    set textfg "#000000"
+
+    shades $bg
+
+    set cvsglb(bg) $bg
+    set cvsglb(fg) $fg
+    set cvsglb(textbg) $textbg
+    set cvsglb(textfg) $textfg
+    set cvsglb(hlbg) $hlbg
+    set cvsglb(hlfg) $hlfg
+
+    option add *Canvas.Background $cvsglb(shadow)
+    option add *Canvas.Foreground black
+    option add *Entry.Background $textbg
+    option add *Entry.Foreground $textfg
+    option add *Entry.selectBackground $hlbg
+    option add *Entry.selectForeground $hlfg
+    option add *Entry.readonlyBackground $bg
+    option add *Listbox.background $textbg
+    option add *Listbox.selectBackground $hlbg
+    option add *Listbox.selectForeground $hlfg
+    option add *Text.Background $textbg
+    option add *Text.Foreground $textfg
+    option add *Text.selectBackground $hlbg
+    option add *Text.selectForeground $hlfg
+    option add *Button.activeForeground $fg
+    option add *Menu.activeForeground $fg
+
+    # checkbuttons and radiobuttons
+    if {$tk_version >= 8.5} {
+       option add *Menu.selectColor $fg
+       option add *Checkbutton.selectColor "#ffffff"
+       option add *Radiobutton.selectColor "#ffffff"
+     } else {
+       option add *selectColor $hlbg
+     }
+
+    if { ! [info exists cvscfg(guifont)] } {
+      set cvscfg(guifont) [lindex [.testlbl configure -font] 4]
+      if {$tk_version >= 8.5} {
+       # This makes it look like tk8.4.  Want?  dunno.
+       font configure TkHeadingFont -size 9
+       set cvscfg(guifont) TkHeadingFont
+       option add *Menu.font $cvscfg(guifont)
+       option add *Label.font $cvscfg(guifont)
+       option add *Button.font $cvscfg(guifont)
+      }
+    }
   }
-  set cvsglb(canvbg) [lindex [.testlbl configure -background] 4]
-  # If we're not in CDE but the background option is set, we're probably
-  # in KDE or Gnome or some such.  It rather rudely sets all the Tk
-  # backgrounds the same which I don't like, so I'm going to use the same
-  # trick I use for CDE to give the canvases a little shading.  I don't
-  # do this for raw X11 because the user might have set their own options.
-  set cvsglb(bg) [lindex [.testlbl cget -background] 0]
-  set cvsglb(fg) [lindex [.testlbl cget -foreground] 0]
-  set cvslb(dfg) [lindex [.testlbl cget -disabledforeground] 0]
-  set cvsglb(canvbg) [rgb_shadow $cvsglb(bg)]
   destroy .testlbl
 
-  #puts "bg $cvsglb(bg)"
-  #puts "canvbg $cvsglb(canvbg)"
-  #puts "hlbg $cvsglb(hlbg)"
-  if {[is_gray $cvsglb(hlbg)]} {
-    # Which is better? I like the yellow
-    #set cvsglb(hlbg) $cvsglb(sel)
-    set sel [option get . selectColor Background]
-    if {$sel != ""} {
-      #puts "option selectColor: $sel"
-      set  cvsglb(hlbg) $sel
-    } else {
-      set cvsglb(hlbg) "#ffec8b"
-    }
-    #puts "Changed hlbg so it won't be gray"
-  }
-  if {[rgb_diff $cvsglb(hlbg) $cvsglb(canvbg)] < 12000} {
-    set cvsglb(hlbg) [rgb_shadow  $cvsglb(hlbg)]
-    #puts "Changed hlbg because it's nearly the same as the canvas ($rgb_diff < 12000)"
-  }
-  #puts "hlbg $cvsglb(hlbg)"
-   
-  scrollbar .scrl
-  destroy .scrl
-
-  if { ! [info exists cvscfg(dialogfont)] } {
+  if {! [info exists cvscfg(dialogfont)]} {
     set cvscfg(dialogfont) $cvscfg(guifont)
   }
 
-  option add *Entry.background $cvsglb(textbg)
-  option add *Label.font $cvscfg(guifont) userDefault
-  option add *Button.font $cvscfg(guifont) userDefault
-  option add *Menu.font $menufont userDefault
-  option add *Scrollbar.troughColor $cvsglb(canvbg) userDefault
-  option add *Canvas.Background $cvsglb(canvbg) userDefault
+  if {$theme_system == "CDE"} {
+    # This makes it consistent with the rest of the CDE interface
+    option add *Menu.font $cvscfg(guifont)
+    option add *Label.font $cvscfg(guifont)
+    option add *Button.font $cvscfg(guifont)
+  }
+  #puts " Theme system: $theme_system"
 } else {
-  set lbf [font actual $cvscfg(listboxfont)]
-  set ffam [lindex $lbf 1]
-  set fsiz [lindex $lbf 3]
-  set cvscfg(listboxfont) [list $ffam $fsiz]
+  # Find out what the default gui font is
+  label .testlbl -text "LABEL"
+  # Find out what the tk default is
+  set cvscfg(guifont) [lindex [.testlbl configure -font] 4]
+  set cvscfg(dialogfont) $cvscfg(guifont)
+
+  set cvsglb(canvbg) [lindex [.testlbl configure -background] 4]
+  set cvsglb(bg) [lindex [.testlbl cget -background] 0]
+  set cvsglb(fg) [lindex [.testlbl cget -foreground] 0]
+  set cvsglb(canvbg) [rgb_shadow $cvsglb(bg)]
+  destroy .testlbl
+  if {$WSYS eq "aqua"} {
+    # keep evertyhing from being blinding white
+    # button highlightbackground has to be the same as background
+    # or else there are little white boxes around the button "pill"
+    option add *background #ebebeb userDefault
+    option add *Button.highlightBackground #ebebeb userDefault
+    # That totally screws up the menus unless you fix it with this
+    option add *Menu.Background white
+    option add *Menu.Foreground black
+
+    option add *Entry.HighlightThickness 2 userDefault
+    option add *Entry.highlightBackground $cvsglb(hlbg) userDefault
+    option add *Canvas.background #eeeeee userDefault
+    option add *Entry.background #ffffff userDefault
+    option add *Text.background white userDefault
+  }
 }
 
+
+# Fonts for the canvas "listboxes"
 set cvscfg(flashfont) $cvscfg(listboxfont)
-#set fsiz [lindex $cvscfg(listboxfont) 1]
+set fsiz [lindex $cvscfg(listboxfont) 1]
 set lbf [font actual $cvscfg(listboxfont)]
+#puts "$tcl_platform(os) $tk_patchLevel   [winfo server .]"
 #puts "listboxfont: $cvscfg(listboxfont)"
 #puts "actual listboxfont: $lbf"
 set ffam [lindex $lbf 1]
 set fsiz [lindex $lbf 3]
 regsub -- {-} $fsiz {} fsiz
 
+if {[tk windowingsystem] eq "x11"} {
+  if {$tk_version >= 8.5} {
+    # Put the help menu back on the right
+    #tk::classic::restore menu
+
+    if {$tcl_platform(os) eq "Linux" && [lindex $tk_patchLevel 2] < 8} {
+      # FIXME: check for X.Org in server string?
+      #puts [winfo server .]
+      # Overstrike and underline fonts in Xorg were too big from 8.5.0 to 8.5.7
+      set fsiz -$fsiz
+    }
+  }
+}
+
 set cvscfg(flashfont) [list $ffam $fsiz underline]
-#puts "\nflashfont: $cvscfg(flashfont)"
+#puts "requested flashfont: $cvscfg(flashfont)"
 #puts "actual flashfont: [font actual $cvscfg(flashfont)]"
-# Prefer underline, but it isn't working at all in tk8.5 on linux
+#puts "try underline: [font actual $cvscfg(flashfont) -underline]"
+# Prefer underline, but it isn't working at all in tk8.5.0 on linux
 if {! [font actual $cvscfg(flashfont) -underline]} {
-  #puts "Underline font not working.  Trying $ffam $fsiz bold"
-  set cvscfg(flashfont) [list $ffam -$fsiz bold]
+  puts "Underline font not working.  Trying $ffam $fsiz bold"
+  puts " (known problem in Tk 8.5.0 on Linux)"
+  set cvscfg(flashfont) [list $ffam $fsiz bold]
 }
 #puts "final flashfont: $cvscfg(flashfont)"
 
@@ -237,7 +319,7 @@ option add *Dialog.msg.font $cvscfg(dialogfont) userDefault
 option add *Message.font $cvscfg(dialogfont) userDefault
 
 
-# Initialize logging (classes are CFTD)
+# Initialize logging (classes are C,F,T,D)
 if { ! [info exists cvscfg(log_classes)] } {
   set cvscfg(log_classes) "C"
 }
@@ -448,3 +530,4 @@ if {[string match {mod*} $cvscfg(startwindow)]} {
 } else {
   workdir_setup
 }
+
